@@ -15,6 +15,7 @@ pub mod kiiroo_v21;
 pub mod kiiroo_v21_initialized;
 pub mod kiiroo_v2_vibrator;
 pub mod lelof1s;
+pub mod lelof1sv2;
 pub mod libo_elle;
 pub mod libo_shark;
 pub mod libo_vibes;
@@ -26,6 +27,7 @@ pub mod lovenuts;
 pub mod magic_motion_v1;
 pub mod magic_motion_v2;
 pub mod magic_motion_v3;
+pub mod magic_motion_v4;
 pub mod mannuo;
 pub mod maxpro;
 pub mod mizzzee;
@@ -116,6 +118,7 @@ pub fn get_default_protocol_map() -> DashMap<String, TryCreateProtocolFunc> {
     "kiiroo-v21-initialized",
   );
   add_to_protocol_map::<lelof1s::LeloF1s>(&map, "lelo-f1s");
+  add_to_protocol_map::<lelof1sv2::LeloF1sV2>(&map, "lelo-f1sv2");
   add_to_protocol_map::<libo_elle::LiboElle>(&map, "libo-elle");
   add_to_protocol_map::<libo_shark::LiboShark>(&map, "libo-shark");
   add_to_protocol_map::<libo_vibes::LiboVibes>(&map, "libo-vibes");
@@ -130,6 +133,7 @@ pub fn get_default_protocol_map() -> DashMap<String, TryCreateProtocolFunc> {
   add_to_protocol_map::<magic_motion_v1::MagicMotionV1>(&map, "magic-motion-1");
   add_to_protocol_map::<magic_motion_v2::MagicMotionV2>(&map, "magic-motion-2");
   add_to_protocol_map::<magic_motion_v3::MagicMotionV3>(&map, "magic-motion-3");
+  add_to_protocol_map::<magic_motion_v4::MagicMotionV4>(&map, "magic-motion-4");
   add_to_protocol_map::<mannuo::ManNuo>(&map, "mannuo");
   add_to_protocol_map::<maxpro::Maxpro>(&map, "maxpro");
   add_to_protocol_map::<mizzzee::MizzZee>(&map, "mizzzee");
