@@ -4,7 +4,11 @@ use crate::{
   core::{
     errors::ButtplugError,
     messages::{
-      self, ButtplugClientMessage, ButtplugMessage, ButtplugMessageValidator, ButtplugServerMessage,
+      self,
+      ButtplugClientMessage,
+      ButtplugMessage,
+      ButtplugMessageValidator,
+      ButtplugServerMessage,
     },
   },
   util::{async_manager, stream::convert_broadcast_receiver_to_stream},
@@ -75,7 +79,7 @@ async fn run_server<ConnectorType>(
             match server_clone.parse_message(client_message.clone()).await {
               Ok(ret_msg) => {
                 if let ButtplugClientMessage::RequestServerInfo(rsi) = client_message {
-                  if remote_event_sender_clone.send(ButtplugRemoteServerEvent::Connected(rsi.client_name().clone())).is_err() {
+                  if remote_event_sender_clone.receiver_count() > 0 && remote_event_sender_clone.send(ButtplugRemoteServerEvent::Connected(rsi.client_name().clone())).is_err() {
                     error!("Cannot send event to owner, dropping and assuming local server thread has exited.");
                   }
                 }
@@ -89,7 +93,7 @@ async fn run_server<ConnectorType>(
                 }
               }
             }
-          }).unwrap();
+          });
         }
       },
       _ = disconnect_notifier.notified().fuse() => {
@@ -102,18 +106,20 @@ async fn run_server<ConnectorType>(
           break;
         }
         Some(msg) => {
-          match &msg {
-            ButtplugServerMessage::DeviceAdded(da) => {
-              if remote_event_sender.send(ButtplugRemoteServerEvent::DeviceAdded(da.device_index(), da.device_name().clone())).is_err() {
-                error!("Cannot send event to owner, dropping and assuming local server thread has exited.");
-              }
-            },
-            ButtplugServerMessage::DeviceRemoved(dr) => {
-             if remote_event_sender.send(ButtplugRemoteServerEvent::DeviceRemoved(dr.device_index())).is_err() {
-               error!("Cannot send event to owner, dropping and assuming local server thread has exited.");
-             }
-            },
-            _ => {}
+          if remote_event_sender.receiver_count() > 0 {
+            match &msg {
+              ButtplugServerMessage::DeviceAdded(da) => {
+                if remote_event_sender.send(ButtplugRemoteServerEvent::DeviceAdded(da.device_index(), da.device_name().clone())).is_err() {
+                  error!("Cannot send event to owner, dropping and assuming local server thread has exited.");
+                }
+              },
+              ButtplugServerMessage::DeviceRemoved(dr) => {
+               if remote_event_sender.send(ButtplugRemoteServerEvent::DeviceRemoved(dr.device_index())).is_err() {
+                 error!("Cannot send event to owner, dropping and assuming local server thread has exited.");
+               }
+              },
+              _ => {}
+            }
           }
           let connector_clone = shared_connector.clone();
           if connector_clone.send(msg).await.is_err() {
@@ -131,7 +137,11 @@ async fn run_server<ConnectorType>(
 
 impl Default for ButtplugRemoteServer {
   fn default() -> Self {
-    Self::new(ButtplugServerBuilder::default().finish().unwrap())
+    Self::new(
+      ButtplugServerBuilder::default()
+        .finish()
+        .expect("Default is infallible"),
+    )
   }
 }
 
